@@ -38,6 +38,23 @@ pub mod create_user {
     pub type APIResponse = UserResponse;
 }
 
+pub mod oauth_google {
+    use super::*;
+
+    #[derive(Debug, Deserialize)]
+    #[serde(rename_all = "camelCase")]
+    pub struct RequestBody {
+        pub code: String,
+    }
+
+    #[derive(Debug, Deserialize)]
+    pub struct PathParams {
+        pub user_id: ID,
+    }
+
+    pub type APIResponse = UserResponse;
+}
+
 pub mod update_user {
     use super::*;
     use nettu_scheduler_domain::Metadata;
